/*********************************************/
/* TeeChart Delphi Component Library 4.0     */
/* Demo                                      */
/* Copyright (c) 1995-1998 by David Berneda  */
/* All rights reserved                       */
/*********************************************/
//---------------------------------------------------------------------------
#include <vcl.h>
#pragma hdrstop

#include "UMultAxi.h"
#include <math.h>
//---------------------------------------------------------------------------
#pragma package(smart_init)
#pragma link "CandleCh"
#pragma link "OHLChart"
#pragma link "TeeComma"
#pragma resource "*.dfm"
TFormMultipleAxes *FormMultipleAxes;
//---------------------------------------------------------------------------
__fastcall TFormMultipleAxes::TFormMultipleAxes(TComponent* Owner)
  : TForm(Owner)
{
}
//---------------------------------------------------------------------------
void TFormMultipleAxes::CheckRightAxis()
{
  if (CheckBox1->Checked) Chart1->RightAxis->StartPosition = Axis1->StartPosition;
}

void __fastcall TFormMultipleAxes::FormCreate(TObject *Sender)
{
  DeltaRotation = 2;
  DeltaAxis1 = 1;
  DeltaAxis2 = 1;
  DeltaRight = 2;
  DeltaLeft = 2;
  DeltaZoom = 2;

  DraggingLine = false;
  ScrollBar1->Position = Chart1->View3DOptions->Rotation;

  Chart1->MarginLeft = 10;
  Chart1->ClipPoints = false;
  Chart1->Gradient->Visible = Chart1->IsScreenHighColor();
  CheckBox5->Checked = Chart1->Gradient->Visible;

  Axis1 = new TChartAxis(Chart1);
  Axis1->Horizontal = false;
  Axis1->StartPosition = 50;
  Axis1->EndPosition = 100;
  Axis1->LabelsFont->Color = Series2->SeriesColor;
  Series2->CustomVertAxis = Axis1;

  Axis2 = new TChartAxis(Chart1);
  Axis2->Horizontal = false;
  Axis2->StartPosition = 0;
  Axis2->EndPosition = 50;
  Axis2->LabelsFont->Color = Series3->SeriesColor;
  Axis2->PositionPercent = -10;
  Axis2->Grid->Visible = false;
  Series3->CustomVertAxis = Axis2;

  Chart1->LeftAxis->EndPosition = 50;
  Chart1->LeftAxis->LabelsFont->Color = Series1->SeriesColor;

  Series1->FillSampleValues(20);
  Series3->FillSampleValues(20);
  Series4->FillSampleValues(120);
  Series2->FillSampleValues(20);

  Series4->VertAxis = aRightAxis;

  Chart1->RightAxis->StartPosition = 50;
  Chart1->RightAxis->Maximum = Series4->YValues->MaxValue*2;
  Chart1->RightAxis->AutomaticMaximum = false;
  Chart1->RightAxis->Grid->Visible = false;
  Chart1->RightAxis->LabelsFont->Color = Series4->SeriesColor;

  Series2->HorizAxis = aTopAxis;
  Chart1->TopAxis->Grid->Visible = false;
  Series2->ZOrder = 0;
}
//---------------------------------------------------------------------------
void __fastcall TFormMultipleAxes::Chart1MouseMove(TObject *Sender,
      TShiftState Shift, int X, int Y)
{
  if (DraggingLine) {
    Chart1->LeftAxis->EndPosition = floor((Y-Chart1->ChartRect.Top)*100.0/Chart1->ChartHeight);
    Axis1->StartPosition = Chart1->LeftAxis->EndPosition;
    Axis2->EndPosition = Chart1->LeftAxis->EndPosition;
    CheckRightAxis();
  } else {
    if (abs(Y-Chart1->LeftAxis->IEndPos)<4)
      Chart1->Cursor = (TCursor)crTeeHand;
    else
      Chart1->Cursor = crDefault;
    Chart1->OriginalCursor = Chart1->Cursor;
  }
}
//---------------------------------------------------------------------------
void __fastcall TFormMultipleAxes::Chart1MouseDown(TObject *Sender,
      TMouseButton Button, TShiftState Shift, int X, int Y)
{
  DraggingLine = (!Timer1->Enabled) && (Chart1->Cursor==crTeeHand);
  Chart1->CancelMouse = DraggingLine;
}
//---------------------------------------------------------------------------
void __fastcall TFormMultipleAxes::Chart1MouseUp(TObject *Sender,
      TMouseButton Button, TShiftState Shift, int X, int Y)
{
  DraggingLine = false;
  Chart1->CancelMouse = false;
}
//---------------------------------------------------------------------------
void __fastcall TFormMultipleAxes::Chart1AllowScroll(TChartAxis *Sender,
      double &AMin, double &AMax, bool &AllowScroll)
{
  AllowScroll = Sender != Chart1->RightAxis;
}
//---------------------------------------------------------------------------
void __fastcall TFormMultipleAxes::CheckBox1Click(TObject *Sender)
{
  CheckRightAxis();
}
//---------------------------------------------------------------------------
void __fastcall TFormMultipleAxes::CheckBox2Click(TObject *Sender)
{
  Chart1->View3D = CheckBox2->Checked;
  Chart1->View3DOptions->Orthogonal = false;
  ScrollBar1->Enabled = Chart1->View3D;
  if (!Chart1->View3D)
    CheckBox9->Checked = false;
}
//---------------------------------------------------------------------------
void __fastcall TFormMultipleAxes::ScrollBar1Change(TObject *Sender)
{
  Chart1->View3DOptions->Rotation = ScrollBar1->Position;
}
//---------------------------------------------------------------------------
void __fastcall TFormMultipleAxes::CheckBox3Click(TObject *Sender)
{
  Timer1->Enabled = CheckBox3->Checked;
  CheckBox1->Enabled = !Timer1->Enabled;
  Chart1->Foot->Visible = !Timer1->Enabled;
  CheckBox4->Enabled = Timer1->Enabled;
  CheckBox9->Enabled = Timer1->Enabled;
}
//---------------------------------------------------------------------------
void CheckDelta(int& D, const double Value, int Min, int Max)
{
  if ((D<0) && (Value<Min+5))
    D = -D;
  else if ((D>0) && (Value>Max-5))
    D = -D;
}

void __fastcall TFormMultipleAxes::Timer1Timer(TObject *Sender)
{
  int MinAngle;
  if (CheckBox9->Checked) {
    Chart1->View3D = true;
    Chart1->View3DOptions->Orthogonal = false;
    Chart1->View3DOptions->Rotation = Chart1->View3DOptions->Rotation+DeltaRotation;
    if (Chart1->Canvas->SupportsFullRotation)
      MinAngle = 0;
    else
      MinAngle = 270;
    CheckDelta(DeltaRotation,Chart1->View3DOptions->Rotation,MinAngle,360);
    Chart1->View3DOptions->Zoom = Chart1->View3DOptions->Zoom+DeltaZoom;
    CheckDelta(DeltaZoom,Chart1->View3DOptions->Zoom,20,120);
  }
  Axis1->StartPosition = Axis1->StartPosition+DeltaAxis1;
  CheckDelta(DeltaAxis1,Axis1->StartPosition,0,75);

  Axis2->StartPosition = Axis2->StartPosition+DeltaAxis2;
  Axis2->EndPosition = Axis2->EndPosition+DeltaAxis2;
  CheckDelta(DeltaAxis2,Axis2->EndPosition,0,95);

  Chart1->RightAxis->PositionPercent =
    Chart1->RightAxis->PositionPercent+DeltaRight;
  CheckDelta(DeltaRight,Chart1->RightAxis->PositionPercent,-10,110);
  Chart1->LeftAxis->PositionPercent = Chart1->LeftAxis->PositionPercent+DeltaLeft;
  CheckDelta(DeltaLeft,Chart1->LeftAxis->PositionPercent,-10,110);
}
//---------------------------------------------------------------------------
void __fastcall TFormMultipleAxes::CheckBox4Click(TObject *Sender)
{
  Chart1->View3DOptions->ZoomText = CheckBox4->Checked;
}
//---------------------------------------------------------------------------
void __fastcall TFormMultipleAxes::CheckBox6Click(TObject *Sender)
{
  Chart1->AxisVisible = CheckBox6->Checked;
}
//---------------------------------------------------------------------------
void __fastcall TFormMultipleAxes::CheckBox5Click(TObject *Sender)
{
  Chart1->Gradient->Visible = CheckBox5->Checked;
}
//---------------------------------------------------------------------------
void __fastcall TFormMultipleAxes::CheckBox7Click(TObject *Sender)
{
  Chart1->Legend->Visible = CheckBox7->Checked;
}
//---------------------------------------------------------------------------
void __fastcall TFormMultipleAxes::CheckBox8Click(TObject *Sender)
{
  Chart1->View3DWalls = CheckBox8->Checked;
  if (Chart1->View3DWalls)
    Chart1->BackWall->Brush->Style = bsSolid;
  else
    Chart1->BackWall->Brush->Style = bsClear;
  Chart1->BackWall->Pen->Visible = Chart1->View3DWalls;
}
//---------------------------------------------------------------------------
void __fastcall TFormMultipleAxes::CheckBox9Click(TObject *Sender)
{
  CheckBox2->Checked = true;
}
//---------------------------------------------------------------------------
void __fastcall TFormMultipleAxes::Button1Click(TObject *Sender)
{
  Close();
}
//---------------------------------------------------------------------------
void __fastcall TFormMultipleAxes::Chart1AfterDraw(TObject *Sender)
{
  // draw an horizontal line at left axis bottom position
  Chart1->Canvas->Pen->Color = clGray;
  Chart1->Canvas->Pen->Width = 2;
  Chart1->Canvas->Pen->Style = psSolid;
  Chart1->Canvas->MoveTo3D(Chart1->ChartRect.Left,Chart1->LeftAxis->IEndPos,0);
  Chart1->Canvas->LineTo3D(Chart1->ChartRect.Right,Chart1->LeftAxis->IEndPos,0);
}
//---------------------------------------------------------------------------
